% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AnoMultiMetric.R
\name{AnoMultiMetric}
\alias{AnoMultiMetric}
\title{Multiple Metrics applied in Multiple Model Anomalies}
\usage{
AnoMultiMetric(data, metric = "correlation", multimodel = TRUE,
  names = NULL)
}
\arguments{
\item{data}{an s2dverification object (list) giving as output of \code{Load} function from S2dverification package.}

\item{metric}{a character string giving the metric for computing the maximum skill. This must be one of the strings 'correlation', 'rms' or 'rmsss.}

\item{multimodel}{a logical value indicating wether a Multi-Model Mean should be computed.}

\item{names}{a character vector indicating the names of the models to be compared.}
}
\value{
A list of 3:
\itemize{
\item\code{$ano} {A list of 2:
\itemize{
   \item\code{$ano_exp} {an array with the same dimensions as the \code{mod} label in the input \code{data}.}
   \item\code{$ano_exp} {an array with the same dimensions as the \code{obs} label in the input \code{data}.}}}
\item\code{$metric} {An array with the same dimensions as the \code{mod} label in the input \code{data} without the 'ftime' dimension containing the correlations coefficients. if \code{multimodel} is TRUE, the greatest first dimension correspons. The third dimension contains the statistics selected: for \code{correlation} and \code{rms} metrics, the third dimension of length four corresponds to the lower limit of the \code{siglev}\% confidence interval, the statistics itselfs, the upper limit of the \code{siglev}\% confidence interval and the \code{siglev}\% significance level, while for the \code{rmsss}, the third dimension of length two corresponds to the statistics itselfs and the p-value of the one-sided Fisher test with Ho: RMSSS = 0.}
\item\code{$names} {A vector containing the names of the models.}}
}
\description{
This function calculates correlation (Anomaly Correlation Coefficient; ACC), root mean square error (RMS) and the root mean square error skill score (RMSSS) of individual anomaly models and multi-models mean (if desired) with the observations.
}
\examples{
mod <- 1 : (2 * 3 * 4 * 5 * 6 * 7)
dim(mod) <- c(dataset = 2, member = 3, sdate = 4, ftime = 5, lat = 6, lon = 7)
obs <- 1 : (1 * 1 * 4 * 5 * 6 * 7)
dim(obs) <- c(dataset = 1, member = 1, sdate = 4, ftime = 5, lat = 6, lon = 7)
lon <- seq(0, 30, 5)
lat <- seq(0, 25, 5)
dat <- list(mod = mod, obs = obs, lat = lat, lon = lon)
a <- AnoMultiMetric(dat)
str(a)
}
\references{
\url{http://link.springer.com/10.1007/s00382-018-4404-z}
}
\seealso{
\code{\link[s2dverification]{Corr}} and \code{link[s2dverification]{Load}}
}
\author{
Mishra Niti, \email{niti.mishra@bsc.es}
}
